<TS language="az" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Yeni bir ünvan yaradın</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Hazırki seçilmiş ünvanı sistem lövhəsinə kopyalayın</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Bağla</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Hazırki seçilmiş ünvanı siyahıdan silin</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Axtarmaq üçün ünvan və ya etiket daxil edin</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Hazırki vərəqdəki verilənləri fayla ixrac edin</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;İxrac</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Pul göndəriləcək ünvanı seçin</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Pul alınacaq ünvanı seçin</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Seç</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Göndərilən ünvanlar</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Alınan ünvanlar</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Bunlar ödənişləri göndərmək üçün Bitcoin ünvanlarınızdır. Pul göndərməkdən əvvəl həmişə miqdarı və göndəriləcək ünvanı yoxlayın.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Ünvanı kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Etiketi kopyala</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Düzəliş et</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Ünvan siyahısını ixrac et</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Vergüllə ayrılmış fayl (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>İxrac edilmədi</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Ünvan siyahısını %1 daxilində saxlamağı sınayarkən xəta baş verdi. Zəhmət olmasa yenidən sınayın.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Ünvan</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yoxdur)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Şifrə İfadə Dialoqu</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Şifrə ifadəsini daxil edin</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Yeni şifrə ifadəsi</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Şifrə ifadəsini təkrarlayın</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Şifrə ifadəsini göstər</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cüzdanı şifrələyin</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Bu əməliyyat, cüzdanın kilidini açmaq üçün cüzdan şifrə ifadəsinə ehtiyac duyur.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Cüzdanın kilidini açın</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Bu əməliyyat, cüzdanın şifrəsini açmaq üçün cüzdan şifrə ifadəsinə ehtiyac duyur.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Cüzdanın şifrəsini açın</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Şifrə ifadəsini dəyişdir</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Cüzdan şifrələməsini təsdiqləyin</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>Unutmayın ki, cüzdanınızın şifrələməsi bitcoinlərinizi kompüterinizə zərərli proqram tərəfindən oğurlanmaqdan tamamilə qoruya bilməz.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Cüzdan şifrələnəcək</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Cüzdanınız şifrələnmək üzrədir.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Cüzdanınız artıq şifrələnib.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Xəbərdarlıq: Caps Lock düyməsi yanılıdır!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;Şifrəli pulqabı...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>&amp;URI aç...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Tənzimləmələr</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Xəbərdarlıq</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Göndərilən ünvanlar</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Alınan ünvanlar</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>Bir pulqabı aç</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Ünvanı kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>&amp;Etiketi kopyala</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Miqdarı kopyalayın</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Dəyişikliyi kopyalayın</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yoxdur)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Şifrəli pulqabı</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Etiket</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Ünvan</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation>Bu tənzimləməni geri almaq bütün blok zəncirinin yenidən endirilməsini tələb edəcək. Əvvəlcə tam zənciri endirmək və sonra budamaq daha sürətlidir. Bəzi qabaqcıl özəllikləri sıradan çıxarar.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Ünvan</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Disables some advanced features but all blocks will still be fully validated. Reverting this setting requires re-downloading the entire blockchain. Actual disk usage may be somewhat higher.</source>
        <translation>Bəzi qabaqcıl özəllikləri sıradan çıxardar, ancaq bütün bloklar tamamilə təsdiqlənmiş qalacaq. Bu tənzimləməni geri almaq bütün blok zəncirinin yenidən endirilməsini tələb edəcək. Aktual disk istifadəsi biraz daha yüksək ola bilər.</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation>Bu tənzimləməni geri almaq bütün blok zəncirinin yenidən endirilməsini tələb edəcək. </translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>&amp;UPnP istifadə edən xəritə portu</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation>İstifadəçi interfeys dili burada tənzimlənə bilər. Bu tənzimləmə %1 yenidən başladıldıqdan sonra təsirli olacaq.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Bağla</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Məlumat</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation>&amp;Sıfırla</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp;Ünvanı kopyala</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Etiket:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Ünvanı kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>&amp;Etiketi kopyala</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Ünvan:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Etiket:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Ünvanı kopyala</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yoxdur)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>Yetərsiz balans</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Seç...</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Miqdarı kopyalayın</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Dəyişikliyi kopyalayın</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yoxdur)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Etiket:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yoxdur)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Other</source>
        <translation>Başqa</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Ünvanı kopyala</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>&amp;Etiketi kopyala</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Vergüllə ayrılmış fayl (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Ünvan</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>İxrac edilmədi</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;İxrac</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Hazırki vərəqdəki verilənləri fayla ixrac edin</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    <message>
        <source>Replaying blocks...</source>
        <translation>Bloklar yenidən səsləndirilir...</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation>Mənbə kodu %s-dən əldə edilə bilər.</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Yetərsiz balans</translation>
    </message>
    <message>
        <source>Fee estimation failed. Fallbackfee is disabled. Wait a few blocks or enable -fallbackfee.</source>
        <translation>Ödəniş təxmin edilmədi. Fallbackfee sıradan çıxarıldı. Bir neçə blok gözləyin və ya Fallbackfee-ni fəallaşdırın.</translation>
    </message>
    <message>
        <source>Warning: Private keys detected in wallet {%s} with disabled private keys</source>
        <translation>Xəbərdarlıq: Gizli açarlar, sıradan çıxarılmış gizli açarlar ilə {%s} pulqabısında aşkarlandı.</translation>
    </message>
    <message>
        <source>Cannot write to data directory '%s'; check permissions.</source>
        <translation>'%s' verilənlər kateqoriyasına yazıla bilmir; icazələri yoxlayın.</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Pulqabı yüklənir...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Yenidən tədqiq edilir...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Yükləmə tamamlandı</translation>
    </message>
</context>
</TS>